@@ -1,8 +1,8 @@
 package Quantum::Superpositions::Lazy::Statistics;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
-use v5.24; use warnings;
+use v5.28; use warnings;
 use Moo;
 
 use feature qw(signatures);
@@ -18,7 +18,7 @@ use List::Util qw(sum);
 # floating point values - 6 digits (IEEE 754)
 use constant HALF_APPROX => "0.500000";
 
-sub transform_states($items, $transformer)
+sub transform_states ($items, $transformer)
 {
 	my @transformed = map {
 		$_->clone_with(value => $transformer)
@@ -27,7 +27,7 @@ sub transform_states($items, $transformer)
 	return \@transformed;
 }
 
-sub weight_to_probability($item, $weight_sum)
+sub weight_to_probability ($item, $weight_sum)
 {
 	return $item->clone_with(
 		weight => sub ($weight) { $weight / $weight_sum }
@@ -36,7 +36,7 @@ sub weight_to_probability($item, $weight_sum)
 	return $item;
 }
 
-sub weighted_mean($list_ref, $weight_sum = undef)
+sub weighted_mean ($list_ref, $weight_sum = undef)
 {
 	$weight_sum = sum map { $_->weight } $list_ref->@*
 		unless defined $weight_sum;
@@ -46,7 +46,7 @@ sub weighted_mean($list_ref, $weight_sum = undef)
 }
 
 # The sorting order is irrelevant here
-sub weighted_median($sorted_list_ref, $average = 0)
+sub weighted_median ($sorted_list_ref, $average = 0)
 {
 	my $approx_half = sub ($value) {
 		return HALF_APPROX eq substr(($value . (0 x length HALF_APPROX)), 0, length HALF_APPROX);
@@ -82,7 +82,8 @@ sub weighted_median($sorted_list_ref, $average = 0)
 
 # CAUTION: float == comparison inside. Will only work for elements
 # that were obtained in a similar fasion
-sub find_border_elements($sorted) {
+sub find_border_elements($sorted)
+{
 	my @found;
 	for my $state (@$sorted) {
 		push @found, $state
@@ -102,21 +103,23 @@ use namespace::clean;
 
 has "parent" => (
 	is => "ro",
-	isa => ConsumerOf["Quantum::Superpositions::Lazy::Role::Collapsible"],
+	isa => ConsumerOf ["Quantum::Superpositions::Lazy::Role::Collapsible"],
 	weak_ref => 1,
 );
 
 # Sorted in ascending order
 has "sorted_by_probability" => (
 	%options,
-	isa => ArrayRef[InstanceOf["Quantum::Superpositions::Lazy::State"]],
+	isa => ArrayRef [InstanceOf ["Quantum::Superpositions::Lazy::State"]],
 	default => sub ($self) {
 		[
 			map {
 				weight_to_probability($_, $self->parent->weight_sum)
-			} nkeysort {
+				}
+				nkeysort {
 				$_->weight
-			} $self->parent->states->@*
+			}
+			$self->parent->states->@*
 		]
 	},
 );
@@ -125,22 +128,22 @@ has "sorted_by_probability" => (
 # (we use sorted_by_probability to avoid copying states twice in weight_to_probability)
 has "sorted_by_value_str" => (
 	%options,
-	isa => ArrayRef[InstanceOf["Quantum::Superpositions::Lazy::State"]],
+	isa => ArrayRef [InstanceOf ["Quantum::Superpositions::Lazy::State"]],
 	default => sub ($self) {
 		[
 			keysort { $_->value }
-				$self->sorted_by_probability->@*
+			$self->sorted_by_probability->@*
 		]
 	},
 );
 
 has "sorted_by_value_num" => (
 	%options,
-	isa => ArrayRef[InstanceOf["Quantum::Superpositions::Lazy::State"]],
+	isa => ArrayRef [InstanceOf ["Quantum::Superpositions::Lazy::State"]],
 	default => sub ($self) {
 		[
 			nkeysort { $_->value }
-				$self->sorted_by_probability->@*
+			$self->sorted_by_probability->@*
 		]
 	},
 );
@@ -148,7 +151,7 @@ has "sorted_by_value_num" => (
 # Other consumer indicator
 has "most_probable" => (
 	%options,
-	isa => InstanceOf["Quantum::Superpositions::Lazy::Superposition"],
+	isa => InstanceOf ["Quantum::Superpositions::Lazy::Superposition"],
 	default => sub ($self) {
 		my @sorted = reverse $self->sorted_by_probability->@*;
 		return Quantum::Superpositions::Lazy::Superposition->new(
@@ -159,7 +162,7 @@ has "most_probable" => (
 
 has "least_probable" => (
 	%options,
-	isa => InstanceOf["Quantum::Superpositions::Lazy::Superposition"],
+	isa => InstanceOf ["Quantum::Superpositions::Lazy::Superposition"],
 	default => sub ($self) {
 		my $sorted = $self->sorted_by_probability;
 		return Quantum::Superpositions::Lazy::Superposition->new(
@@ -185,6 +188,7 @@ has "median_num" => (
 has "mean" => (
 	%options,
 	default => sub ($self) {
+
 		# since the mean won't return a state, we're free not
 		# to make copies of the states.
 		weighted_mean($self->parent->states, $self->parent->weight_sum);
@@ -194,10 +198,14 @@ has "mean" => (
 has "variance" => (
 	%options,
 	default => sub ($self) {
+
 		# transform_states is required here so that we don't modify existing states
-		weighted_mean(transform_states($self->parent->states, sub { $_[0] ** 2 }), $self->parent->weight_sum)
+		weighted_mean(
+			transform_states($self->parent->states, sub { $_[0]**2 }),
+			$self->parent->weight_sum
+			)
 			-
-		$self->mean ** 2
+			$self->mean**2;
 	},
 );
 
@@ -240,9 +248,20 @@ methods internally to avoid multiple invocations of possibly costly
 calculations. Modifying the returned reference contents will change the value
 stored in the cache and will thus lead to wrong values being returned.
 
+Any method that returns states will no longer return the weight of the state,
+but instead will reuse that field for the calculated probability (a float value
+in between 0 and 1). The value can still be treated as weight (and weight sum
+is then 1), but the information on the original weight will not be accessible.
+
+For example, if we use the I<most_probable> method on a superposition that has
+a state with a weight of 3 and the total weight sum is 6, the resulting state
+in the superposition returned by the method will have its I<weight> field equal
+to 0.5.
+
 =head2 parent
 
-Returns the superposition which is used for getting the states data, a consumer of L<Quantum::Superpositions::Lazy::Role::Collapsible>.
+Returns the superposition which is used for getting the states data, a consumer
+of L<Quantum::Superpositions::Lazy::Role::Collapsible>.
 
 =head2 sorted_by_probability
 
@@ -254,7 +273,8 @@ Returns all the states sorted by probability in ascending order.
 
 =head2 sorted_by_value_num
 
-Returns all the states sorted by their value in ascending order. Values can be treated either as numbers or strings in the comparison.
+Returns all the states sorted by their value in ascending order. Values can be
+treated either as numbers or strings in the comparison.
 
 The I<sorted_by_value> method is an alias for I<sorted_by_value_str>.
 
@@ -262,13 +282,16 @@ The I<sorted_by_value> method is an alias for I<sorted_by_value_str>.
 
 =head2 least_probable
 
-Returns the border elements based on weight - the most or the least probable elements. The return value is a new superposition which contains the border elements. Multiple border elements will be grouped in this superposition.
+Returns the border elements based on weight - the most or the least probable
+elements. The return value is a new superposition which contains the border
+elements. Multiple border elements will be grouped in this superposition.
 
 =head2 median
 =head2 median_str
 =head2 median_num
 
-Returns the weighted median of the superposition states (a floating point value). The string variant and the numerical variant differ in two ways:
+Returns the weighted median of the superposition states (a floating point
+value). The string variant and the numerical variant differ in two ways:
 
 =over
 
@@ -284,7 +307,9 @@ The I<median> method is an alias for I<median_str>.
 
 =head2 expected_value
 
-Returns the weighted mean of the data set (a floating point value). The expected value of the discrete set is equal to its weighted mean, hence the I<expected_value> is just an alias for convenience.
+Returns the weighted mean of the data set (a floating point value). The
+expected value of the discrete set is equal to its weighted mean, hence the
+I<expected_value> is just an alias for convenience.
 
 =head2 variance
 
@@ -292,5 +317,6 @@ Returns the variance of the data set (a floating point value).
 
 =head2 standard_deviation
 
-Returns the standard deviation of the data set - a square root of variance (a floating point value).
+Returns the standard deviation of the data set - a square root of variance (a
+floating point value).
 
